@@ -46,9 +46,7 @@ class DependencyMonkey:
 
     resolver = attr.ib(type=Resolver, kw_only=True)
     stack_output = attr.ib(type=str, kw_only=True, default="-")
-    context = attr.ib(
-        type=Optional[Dict[Any, Any]], default=attr.Factory(dict), kw_only=True
-    )
+    context = attr.ib(type=Optional[Dict[Any, Any]], default=attr.Factory(dict), kw_only=True)
     dry_run = attr.ib(type=bool, default=False, kw_only=True)
     decision_type = attr.ib(type=DecisionType, default=DecisionType.ALL, kw_only=True)
 
@@ -68,35 +66,23 @@ class DependencyMonkey:
             _LOGGER.warning("Ignoring user_stack_scoring flag in dependency monkey runs")
         if self.dry_run:
             _LOGGER.warning("Dry run of Dependency Monkey is set, stacks will be just computed")
-            output_func = partial(  # type: ignore
-                self._dm_dry_run, self.stack_output
-            )
+            output_func = partial(self._dm_dry_run, self.stack_output)
         elif self.stack_output == "-":
-            _LOGGER.debug(
-                "Results of Dependency Monkey run will be printed to standard output"
-            )
-            output_func = self._dm_stdout_output
+            _LOGGER.debug("Results of Dependency Monkey run will be printed to standard output")
+            output_func = self._dm_stdout_output  # type: ignore
         elif self.stack_output.startswith(("https://", "http://")):
             _LOGGER.debug(
-                "Results of Dependency Monkey run will be submitted to API endpoint %r",
-                self.stack_output,
-            )
-            output_func = partial(  # type: ignore
-                self._dm_amun_output, self.stack_output, self.context or {}
+                "Results of Dependency Monkey run will be submitted to API endpoint %r", self.stack_output,
             )
+            output_func = partial(self._dm_amun_output, self.stack_output, self.context or {})  # type: ignore
         else:
             _LOGGER.debug(
-                "Results of Dependency Monkey run will be stored in directory %r",
-                self.stack_output,
-            )
-            output_func = partial(  # type: ignore
-                self._dm_dir_output, self.stack_output
+                "Results of Dependency Monkey run will be stored in directory %r", self.stack_output,
             )
+            output_func = partial(self._dm_dir_output, self.stack_output)  # type: ignore
 
         report = DependencyMonkeyReport()
-        for count, product in enumerate(
-            self.resolver.resolve_products(with_devel=with_devel)
-        ):
+        for count, product in enumerate(self.resolver.resolve_products(with_devel=with_devel)):
             count += 1
             _LOGGER.info(
                 "Submitting stack %d with score %g and justification:\n%s",
@@ -122,36 +108,28 @@ class DependencyMonkey:
         return report
 
     @staticmethod
-    def _dm_dry_run(
-        output: str, count: int, _: Project
-    ) -> None:
+    def _dm_dry_run(output: str, count: int, _: Project) -> None:  # noqa: D401
         """A wrapper around dry-run flag."""
-        _LOGGER.info(
-            "Stack %d would be outputted to %r, but dry run flag was set, skipping...",
-            count,
-            output
-        )
+        _LOGGER.info("Stack %d would be outputted to %r, but dry run flag was set, skipping...", count, output)
         return None
 
     @staticmethod
     def _dm_amun_output(
         output: str, context: Dict[Any, Any], count: int, generated_project: Project
-    ) -> str:
+    ) -> str:  # noqa: D401
         """A wrapper around Amun inspection call."""
         context = dict(context)
         context["python"] = generated_project.to_dict()
         # No need to supply runtime environment information.
         context["python"].pop("runtime_environment", None)
         response = amun.inspect(output, **context)
-        _LOGGER.info(
-            "Submitted Amun inspection #%d: %r", count, response["inspection_id"]
-        )
+        _LOGGER.info("Submitted Amun inspection #%d: %r", count, response["inspection_id"])
         _LOGGER.debug("Full Amun response: %s", response)
         inspection_id: str = response["inspection_id"]
         return inspection_id
 
     @staticmethod
-    def _dm_dir_output(output: str, count: int, generated_project: Project) -> str:
+    def _dm_dir_output(output: str, count: int, generated_project: Project) -> str:  # noqa: D401
         """A wrapper for placing generated software stacks onto filesystem."""
         _LOGGER.debug("Writing stack %d", count)
 
@@ -159,14 +137,12 @@ class DependencyMonkey:
         os.makedirs(path, exist_ok=True)
 
         _LOGGER.info("Writing project into output directory %r", path)
-        generated_project.to_files(
-            os.path.join(path, "Pipfile"), os.path.join(path, "Pipfile.lock")
-        )
+        generated_project.to_files(os.path.join(path, "Pipfile"), os.path.join(path, "Pipfile.lock"))
 
         return path
 
     @staticmethod
-    def _dm_stdout_output(count: int, generated_project: Project) -> None:
+    def _dm_stdout_output(count: int, generated_project: Project) -> None:  # noqa: D401
         """A function called if the project should be printed to stdout as a dict."""
         _LOGGER.debug("Printing stack %d", count)
         json.dump(generated_project.to_dict(), fp=sys.stdout, sort_keys=True, indent=2)
