@@ -383,13 +383,15 @@ class Resolver:
                 if step_justification_addition is not None:
                     justification_addition.extend(step_justification_addition)
 
-        if state.unresolved_dependencies:
+        if state.unresolved_dependencies and package_version_tuple[0] in state.unresolved_dependencies:
             cloned_state = state.clone()
             weakref.finalize(cloned_state, self.predictor.finalize_state, id(cloned_state)).atexit = False
         else:
             # Optimization - reuse the old one as it would be discarded anyway.
             cloned_state = state
-            if not user_stack_scoring and (score_addition != 0.0 or not unresolved_dependencies):
+            if not user_stack_scoring and (
+                score_addition != 0.0 or (not state.unresolved_dependencies and not unresolved_dependencies)
+            ):
                 self.beam.remove(cloned_state)
 
         if unresolved_dependencies:
@@ -968,11 +970,10 @@ class Resolver:
         self.stop_resolving = False
         with _sigint_handler(self):
             while not self.stop_resolving:
-                if self.context.accepted_final_states_count + self.context.discarded_final_states_count >= self.limit:
+                if self.context.accepted_final_states_count >= self.limit:
                     _LOGGER.info(
-                        "Reached limit of stacks to be generated - %r (limit is %r), stopping resolver "
+                        "Reached limit of stacks to be generated (limit is %r), stopping resolver "
                         "with the current beam size %d in iteration %d",
-                        self.context.accepted_final_states_count,
                         self.limit,
                         self.beam.size,
                         self.context.iteration,
