@@ -31,7 +31,5 @@ class Sieve(Unit):
     """Sieve base class implementation."""
 
     @abc.abstractmethod
-    def run(
-        self, package_versions: Generator[PackageVersion, None, None]
-    ) -> Generator[PackageVersion, None, None]:
-        """Main entry-point for sieves to filter and score packages."""
+    def run(self, package_versions: Generator[PackageVersion, None, None]) -> Generator[PackageVersion, None, None]:
+        """Run main entry-point for sieves to filter and score packages."""
